********************************************************************
* Program....: PARSEPHY.PRG
* Version....: 1.2
* Author.....: Ted Roche
* Date.......: June 7, 2000
* Notice.....: Copyright  2000 Ted Roche, All Rights Reserved.
* Compiler...: Visual FoxPro 07.00.0000.9465 for Windows
* Abstract...: Parse the physical file list
* ...........: Given a physical file list, create a temporary cursor
* ...........: with each file, whether is is a source or delta file,
*............: and its size on disk
* Parameters.: tcFileName - fully-qualified path and filename of 
* ...........:              physical file list
* ...........: tcPath - path to actual data directory
* Returns....: .F. if parameters, dialogs not supplied
* Changes....: June 11, 2002 - corrected typos with "curlist" misspelled
* ...........:                 as "current" - tr
********************************************************************

LPARAMETERS tcFilename, tcPath

* Validate the source filename
IF EMPTY(tcFileName) or VARTYPE(tcFileName) <>  "C" OR NOT FILE(tcFileName)
  tcFileName = GETFILE()
ENDIF

IF NOT FILE(tcFileName)
  RETURN .F.
ENDIF

* Validate the path
IF EMPTY(tcPath) or VARTYPE(tcPath) # "C" OR NOT DIRECTORY(tcPath)
  tcPath = GETDIR()
ENDIF

IF NOT DIRECTORY(tcPath)
  RETURN .F.
ENDIF

* Declare and initialize variables
LOCAL lcFileName, lcLine, lnLine, lcPath, lcVSSPath
lcFileName = tcFileName
lnLine = 1
lcVSSPath = tcPath

* Create the target cursor
CREATE CURSOR curlist ;
   (mFilePath M, cFileName C(8), iFileSize i, iSrcSize i)
INDEX ON cFilename TAG cFilename


* Import the Physical File List into a temporary cursor
SELECT 0  && select an unused work area
CREATE CURSOR fred (cString C(254))
APPEND FROM (lcFilename) TYPE SDF

GO TOP
lcLine = ALLTRIM(Fred.cString)

* First line is the sourceSafe root: $/, usually aaaaaaaa
lcPath = "$/:"
* Add into to the target database
INSERT INTO curList ;
  VALUES (lcPath, UPPER(ALLTRIM(lcLine)), 0, 0)
SKIP

* Add the rest of the files
SCAN REST
  lnLine = lnLine + 1
  lcLine = ALLTRIM(Fred.cString)
  
  IF EMPTY(lcLine) && SKIP EMPTY LINES
    LOOP
  ENDIF
  IF RIGHT(lcLine,1) = ":"  && it's a path
    lcPath = lcLine
  ELSE  && if it's not a path, it's a file
     INSERT INTO curList ;
        VALUES (lcPath + alltrim(LEFT(lcLine,32)), ;
                RIGHT(lcLine,8), 0, 0)
  ENDIF  && it's a path
ENDSCAN  && REST

* Now update the files for size
LOCAL laDir[1], lnCount, lcSubDir

SELECT curList

LOCAL lcFile
FOR m.i = 0 to 25  && loop "A" through "Z"
   lcSubDir = lcVSSPath + CHR(ASC("A")+ m.i) + "\*.*"
   lnCount = ADIR(laDir, lcSubDir)
   WAIT WINDOW NOWAIT "Updating directory " + lcSubDir
   FOR m.j = 1 to lnCount
     lcFile = UPPER(laDir[m.j,1])
      * For each file, see if it exists in the cursor, and
      * if so, update the size of the file
      * LOCATE FOR cFileName = UPPER(laDir[m.j,1])  && filename, no extension
      * We use SEEK rather than UPDATE because we only want to save the size once - 
      * shared files are referred to more than once.
      IF SEEK(JUSTSTEM(lcFile))
        IF EMPTY(JUSTEXT(lcFile))  && it's a VSS delta file, not source
          REPLACE iFileSize with laDir[m.j,2]
        ELSE
          REPLACE iSrcSize with laDir[m.j,2]
        ENDIF
      ENDIF
   ENDFOR &&* m.j = 1 to lnCount
   
ENDFOR &&* m.i = 0 to 25

WAIT CLEAR
BROWSE TITLE "Raw Results" ;
  FIELDS File=left(mFilePath,50), ;
         cFilename, iFileSize, iSrcSize

* Get top-level Groups with:
WAIT WINDOW NOWAIT "Calculating totals..."
SELECT PADR(LEFT(mFilePath,AT("/",mFilePath,2)),20) as cTopGroup, ;
       COUNT(*) ;
 FROM curlist ;
 HAVING NOT EMPTY(cTopGroup) ;
 GROUP by 1 ;
 ORDER by 1 ;
 INTO CURSOR TopGroup
 
* Now, show the total of the file sizes grouped by their top-level
SELECT topgroup.cTopGroup, ;
       SUM(iFileSize), ;
       SUM(iSrcSize), ;
       SUM(iFileSize+iSrcSize) as iTotal ;
  FROM TopGroup inner join curlist ;
       ON Curlist.mFilePath = ALLTRIM(cTopGroup) ;
 GROUP BY 1 ;
 ORDER BY 3 DESC ;
  INTO CURSOR SizeByGroup
  
WAIT CLEAR
SELECT SizeByGroup
BROWSE TITLE "File Sizes by Top-Level Projects"

* Generate an output file and display it 
REPORT FORMAT projsize TO FILE projsize.rpt ASCII NOCONSOLE
WAIT WINDOW NOWAIT "Report saved to disk as ProjSize.RPT"
MODIFY FILE PROJSIZE.RPT


